summaryrefslogtreecommitdiff
path: root/src/termchar.h
diff options
context:
space:
mode:
authorJim Blandy <jimb@redhat.com>1992-07-13 20:56:17 +0000
committerJim Blandy <jimb@redhat.com>1992-07-13 20:56:17 +0000
commit39f1f913b56985780d808691a28704b13f2d73ec (patch)
tree810b32e310263721e980b1c5796c0a6c2a179bd8 /src/termchar.h
parent717ac510b968e5e1114cd8b9a72c20574ef60042 (diff)
downloademacs-39f1f913b56985780d808691a28704b13f2d73ec.tar.gz
entered into RCS
Diffstat (limited to 'src/termchar.h')
-rw-r--r--src/termchar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/termchar.h b/src/termchar.h
index 7a93d762bb4..7741292695e 100644
--- a/src/termchar.h
+++ b/src/termchar.h
@@ -30,14 +30,14 @@ extern int line_ins_del_ok; /* Terminal can insert and delete lines */
extern int char_ins_del_ok; /* Terminal can insert and delete chars */
extern int scroll_region_ok; /* Terminal supports setting the scroll
window */
-extern int memory_below_screen; /* Terminal remembers lines scrolled
+extern int memory_below_frame; /* Terminal remembers lines scrolled
off bottom */
extern int fast_clear_end_of_line; /* Terminal has a `ce' string */
extern int dont_calculate_costs; /* Nonzero means don't bother computing
various cost tables; we won't use them. */
/* Nonzero means no need to redraw the entire screen on resuming
a suspended Emacs. This is useful on terminals with multiple pages,
where one page is used for Emacs and another for all else. */
extern int no_redraw_on_reenter;
@@ -30,14 +30,14 @@ extern int line_ins_del_ok; /* Terminal can insert and delete lines */
extern int dont_calculate_costs; /* Nonzero means don't bother computing
various cost tables; we won't use them. */
-/* Nonzero means no need to redraw the entire screen on resuming
+/* Nonzero means no need to redraw the entire frame on resuming
a suspended Emacs. This is useful on terminals with multiple pages,
where one page is used for Emacs and another for all else. */